==> hermes-2.3.4-a0a42686.tar.gz: hermes-2.3.4-a0a42686/spec/libs/bo_client/tasks/application_task_spec.rb <==
require 'rails_helper'

# exemple d'utilisation
=begin
hr = Hermes::HousingRequest.first
ho= Hermes::HousingOffer.first
so=Hermes::BoClient::UpdateStatusTask.new({:'housing_request_id'=> hr.id,housing_offer_id: ho.id})
so.to_xml
so.execute
=end

dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'StatutProposition.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::UpdateStatusTask, type: :helper do

  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }
  let!(:user1) { create(:user) }
  let!(:applicant1) {
    create(
        :applicant,
        user: user1,
        monthly_charges: {},
        work_contract_type: "alpha",
        has_other_employers: true,
        year_minus_one: Date.new,
        amount_year_minus_one: 1.23,
        birth_date:DateTime.new,
        nationality:"alpha",
        family_situation:"alpha",
        civility:"alpha"
    )
  }

  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_request' do
    let!(:applicant) {create(:applicant)}
    let!(:housing_offer1) do
      create(
          :housing_offer,
          typology: 'T2',
          external_ref: 'blabli'
      )
    end

    let!(:housing_request1) do
      create(
          :housing_request,
          is_active: true,
          main_applicant: applicant1,
          id_counter: "alpha",
          internal_ref: "alpha",
          sne_creation_date: DateTime.new,
          forcing_duplicate: true,
          electronical_renewal: true,
          seeked_housing_categories: ["alpha"],
          seeking_first_floor: true,
          seeking_elevator: true,
          seeked_max_rent: 451,
          widen_request: true,
          seeked_types: ["alpha", "bravo"],
          seeked_districts: ["alpha", "bravo"],
          seeked_district_postal_codes: ["alpha", "bravo"],
          motivation3: "alpha",
          requester_lastname: "alpha",
          requester_firstname: "alpha",
      )

    end
    let!(:housing_application1) {create(:housing_application, housing_offer_id: housing_offer1.id,
                                               housing_request_id: housing_request1.id)}

    let!(:update_status_task1) do
      build(
        :application_task,
        options: {housing_application_id: housing_application1.id, housing_request_id: housing_request1.id ,housing_offer_id: housing_offer1.id}
      )
    end

    describe 'using to_xml' do
      it 'should return a valid xml' do
        expect(xsd.validate(Nokogiri::XML(update_status_task1.to_xml))).to be_present
        update_status_task1.execute
        VCR.use_cassette("update_status_task", :match_requests_on => [:method, :uri, :path]) do
          perform_enqueued_jobs do
            enqueued_jobs.each {|job| job[:job].perform_now(*job[:args])}
          end
        end
        ap housing_application1.reload.last_error_responses
        expect(housing_application1.reload.last_error_responses.length).to eq(1)
        expect(housing_application1.reload.last_send_has_error).to eq(true)
      end
    end
  end
end

==> hermes-2.3.4-72367283.tar.gz: hermes-2.3.4-72367283/spec/libs/bo_client/tasks/application_task_spec.rb <==
require 'rails_helper'

# exemple d'utilisation
=begin
hr = Hermes::HousingRequest.first
ho= Hermes::HousingOffer.first
so=Hermes::BoClient::UpdateStatusTask.new({:'housing_request_id'=> hr.id,housing_offer_id: ho.id})
so.to_xml
so.execute
=end

dir_path = File.dirname(__FILE__)
schema_path = [dir_path, 'StatutProposition.xsd'].join('/')
require [Hermes::Engine.root, %w[lib hermes bo_client tasks]].flatten.join('/').to_s

RSpec.describe Hermes::BoClient::UpdateStatusTask, type: :helper do

  let!(:xsd) { Nokogiri::XML::Schema(File.read(schema_path)) }
  let!(:user1) { create(:user) }
  let!(:applicant1) {
    create(
        :applicant,
        user: user1,
        monthly_charges: {},
        work_contract_type: "alpha",
        has_other_employers: true,
        year_minus_one: Date.new,
        amount_year_minus_one: 1.23,
        birth_date:DateTime.new,
        nationality:"alpha",
        family_situation:"alpha",
        civility:"alpha"
    )
  }
  
  it 'should load a valid XSD' do
    expect(xsd).to be_present
    expect(xsd.class).to be Nokogiri::XML::Schema
  end

  context 'with simple housing_request' do
    let!(:applicant) {create(:applicant)}
    let!(:housing_offer1) do
      create(
          :housing_offer,
          typology: 'T2',
          external_ref: 'blabli'
      )
    end

    let!(:housing_request1) do
      create(
          :housing_request,
          is_active: true,
          main_applicant: applicant1,
          id_counter: "alpha",
          internal_ref: "alpha",
          sne_creation_date: DateTime.new,
          forcing_duplicate: true,
          electronical_renewal: true,
          seeked_housing_categories: ["alpha"],
          seeking_first_floor: true,
          seeking_elevator: true,
          seeked_max_rent: 451,
          widen_request: true,
          seeked_types: ["alpha", "bravo"],
          seeked_districts: ["alpha", "bravo"],
          seeked_district_postal_codes: ["alpha", "bravo"],
          motivation3: "alpha",
          requester_lastname: "alpha",
          requester_firstname: "alpha",
      )
  
    end
    let!(:housing_application1) {create(:housing_application, housing_offer_id: housing_offer1.id,
                                               housing_request_id: housing_request1.id)}

    let!(:update_status_task1) do
      build(
        :application_task,
        options: {housing_application_id: housing_application1.id, housing_request_id: housing_request1.id ,housing_offer_id: housing_offer1.id}
      )
    end

    describe 'using to_xml' do
      it 'should return a valid xml' do
        puts update_status_task1.to_xml
        ap update_status_task1.validate_xml
=begin
update_status_task1.validate_xml

expect(housing_application1.reload.last_xml_validation_report).to eq("[]")
=end
        expect(xsd.validate(Nokogiri::XML(update_status_task1.to_xml))).to be_present
      end
    end
  end
end
